/*  Copyright (C) 2014 Moritz Becker

	This file is part of Charon.

	Charon is free software: you can redistribute it and/or modify
	it under the terms of the GNU Lesser General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	Charon is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU Lesser General Public License for more details.

	You should have received a copy of the GNU Lesser General Public License
	along with Charon.  If not, see <http://www.gnu.org/licenses/>.
*/
/** \file BlurByDepth.h
 *  Declaration of the parameter class BlurByDepth.
 *  \author <a href="mailto:moritz.becker@iwr.uni-heidelberg.de">
 *      Moritz Becker</a>
 *  \date 07.05.2014
 */

#ifndef _BLURBYDEPTH_H_
#define _BLURBYDEPTH_H_

#ifdef _MSC_VER
#ifdef blurbydepth_EXPORTS
/// Visual C++ specific code
#define blurbydepth_DECLDIR __declspec(dllexport)
#else
#define blurbydepth_DECLDIR __declspec(dllimport)
#endif /*Export or import*/
#else
/// Not needed without MSVC
#define blurbydepth_DECLDIR
#endif

#include <charon-core/ParameteredObject.h>
#include <charon-utils/CImg.h>

/// Blurs an image depending on depths of a given depth map
/** Blurs an image depending on depths of a given depth map
 */
template <typename T>
class blurbydepth_DECLDIR BlurByDepth :
		public TemplatedParameteredObject<T> {
public:
	/// default constructor
	/// \param name          Instance name
	BlurByDepth(const std::string& name = "");

	/// Images to blur
	InputSlot< cimg_library::CImgList<T> > images;
	/// Depthmaps for depth dependen blur
	InputSlot< cimg_library::CImgList<T> > depthmaps;

	/// Blurred images
	OutputSlot< cimg_library::CImgList<T> > blurred;
	
	/// Quadratic scheme
	Parameter< bool > blurQuadratic;
	/// depth to start blur with blurNear
	Parameter< float > depthNear;
	/// depth to end blur with blurFar
	Parameter< float > depthFar;
	/// blur kernel for nearest points
	Parameter< float > blurNear;
	/// blur kernel for farest point
	Parameter< float > blurFar;
	/// Assume two images per depthmap
	Parameter< bool > stereo;
	/// Use given max and min values for all frames
	Parameter< bool > useMaxMinValues;
	/// Maxmimum value of all images
	Parameter< float > maxValue;
	/// Minimum value of all images
	Parameter< float > minValue;


protected:
	/// Update object.
	virtual void execute();
};

#endif // _BLURBYDEPTH_H_
