/*  Copyright (C) 2014 Moritz Becker

	This file is part of Charon.

	Charon is free software: you can redistribute it and/or modify
	it under the terms of the GNU Lesser General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	Charon is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU Lesser General Public License for more details.

	You should have received a copy of the GNU Lesser General Public License
	along with Charon.  If not, see <http://www.gnu.org/licenses/>.
*/
/** \file DrawBoxes.h
 *  Declaration of the parameter class DrawBoxes.
 *  \author <a href="mailto:moritz.becker@iwr.uni-heidelberg.de">
 *      Moritz Becker</a>
 *  \date 19.05.2014
 */

#ifndef _DRAWBOXES_H_
#define _DRAWBOXES_H_

#ifdef _MSC_VER
#ifdef drawboxes_EXPORTS
/// Visual C++ specific code
#define drawboxes_DECLDIR __declspec(dllexport)
#else
#define drawboxes_DECLDIR __declspec(dllimport)
#endif /*Export or import*/
#else
/// Not needed without MSVC
#define drawboxes_DECLDIR
#endif

#include <charon-core/ParameteredObject.h>
#include <charon-utils/CImg.h>

#include <charon-utils/Annotation.hxx>

/// Draw boxes on given images
/** Draw boxes on given images
 */
template <typename T>
class drawboxes_DECLDIR DrawBoxes :
		public TemplatedParameteredObject<T> {
public:
	/// default constructor
	/// \param name          Instance name
	DrawBoxes(const std::string& name = "");
	
	/// annotation values
	InputSlot< annotation::AnnotationList > annotations;

	/// vector of image file names 
	InputSlot< std::vector< std::string > > filepaths;

	/// Output images
	OutputSlot< cimg_library::CImgList<T> > images;

	/// draw final results
	Parameter< bool > resultsFinal;
	/// draw add results
	Parameter< bool > resultsAdd;
	/// draw failed results
	Parameter< bool > resultsFailed;
	/// draw edit results
	Parameter< bool > resultsEdit;
	/// draw done results
	Parameter< bool > resultsDone;

	/// Save all input images whether with or without drawn boxes. Otherwise,
	/// only images with boxes are saved.
	Parameter< bool > processAll;
	
	/// Color to be used for paint
	Parameter< unsigned int > colorR;
	/// Color to be used for paint
	Parameter< unsigned int > colorG;
	/// Color to be used for paint
	Parameter< unsigned int > colorB;
	
	/// Wrong Color to be used for paint
	Parameter< unsigned int > colorRWrong;
	/// Wrong Color to be used for paint
	Parameter< unsigned int > colorGWrong;
	/// Wrong Color to be used for paint
	Parameter< unsigned int > colorBWrong;

	/// Wrong Color to be used for paint
	Parameter< unsigned int > colorRFinal;
	/// Wrong Color to be used for paint
	Parameter< unsigned int > colorGFinal;
	/// Wrong Color to be used for paint
	Parameter< unsigned int > colorBFinal;

	/// Final wrong Color to be used for paint
	Parameter< unsigned int > colorRFinalWrong;
	/// Final wrong Color to be used for paint
	Parameter< unsigned int > colorGFinalWrong;
	/// Final wrong Color to be used for paint
	Parameter< unsigned int > colorBFinalWrong;


protected:
	/// Update object.
	virtual void execute();
};

#endif // _DRAWBOXES_H_
