/*  Copyright (C) 2014 Moritz Becker

	This file is part of Charon.

	Charon is free software: you can redistribute it and/or modify
	it under the terms of the GNU Lesser General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	Charon is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU Lesser General Public License for more details.

	You should have received a copy of the GNU Lesser General Public License
	along with Charon.  If not, see <http://www.gnu.org/licenses/>.
*/
/** \file AnnotationWriter.cpp
 *  Implementation of parameter class AnnotationWriter.
 *  \author <a href="mailto:moritz.becker@iwr.uni-heidelberg.de">
 *      Moritz Becker</a>
 *  \date 21.05.2014
 */

#include <charon-core/ParameteredObject.hxx>
#include "../include/charon-utils/AnnotationWriter.h"

AnnotationWriter::AnnotationWriter(const std::string& name) :
		ParameteredObject(
			"AnnotationWriter", name,
			"<h2>Writes annotation objects back to a JSON file</h2><br>"
			"Writes annotation objects back to a JSON file"
		)
{

	ParameteredObject::_addInputSlot(
		annotation, "annotation",
		"AnnotationList Object",
		"annotationList");

	ParameteredObject::_addParameter(
		jsonFile, "jsonFile",
		"File path to new JSON file",
		"FileWrite");

}

void AnnotationWriter::execute() {
	// your code goes here :-)
}

// the following functions are needed
// for class AnnotationWriter to work as a charon plugin.
extern "C" annotationwriter_DECLDIR ParameteredObject*
		create(const std::string& name, ParameteredObject::template_type) {
	return new AnnotationWriter(name);
}

extern "C" annotationwriter_DECLDIR void destroy(ParameteredObject* b) {
	delete b;
}

/// Report build configuration to prevent linking of incompatibel runtime libs
extern "C" annotationwriter_DECLDIR ParameteredObject::build_type getBuildType() {
#ifdef _DEBUG
	return ParameteredObject::DEBUG_BUILD;
#else
	return ParameteredObject::RELEASE_BUILD;
#endif
}
